diff roundup/mailgw.py @ 615:7c2c4840db6a

[SF#516883] mail interface + ANONYMOUS_REGISTER
author Richard Jones <richard@users.sourceforge.net>
date Thu, 14 Feb 2002 23:46:02 +0000
parents 633f2b542146
children 08abec25b2c6
line wrap: on
line diff
--- a/roundup/mailgw.py	Thu Feb 14 23:39:18 2002 +0000
+++ b/roundup/mailgw.py	Thu Feb 14 23:46:02 2002 +0000
@@ -73,7 +73,7 @@
 an exception, the original message is bounced back to the sender with the
 explanatory message given in the exception. 
 
-$Id: mailgw.py,v 1.63 2002-02-12 08:08:55 grubert Exp $
+$Id: mailgw.py,v 1.64 2002-02-14 23:46:02 richard Exp $
 '''
 
 
@@ -444,11 +444,15 @@
         # handle the users
         #
 
-        # Don't create users if ANONYMOUS_REGISTER is denied
-        if self.instance.ANONYMOUS_REGISTER == 'deny':
+        # Don't create users if ANONYMOUS_REGISTER_MAIL is denied
+        # ... fall back on ANONYMOUS_REGISTER if the other doesn't exist
+        create = 1
+        if hasattr(self.instance, 'ANONYMOUS_REGISTER_MAIL'):
+            if self.instance.ANONYMOUS_REGISTER_MAIL == 'deny':
+                create = 0
+        elif self.instance.ANONYMOUS_REGISTER == 'deny':
             create = 0
-        else:
-            create = 1
+
         author = self.db.uidFromAddress(message.getaddrlist('from')[0],
             create=create)
         if not author:
@@ -786,6 +790,9 @@
 
 #
 # $Log: not supported by cvs2svn $
+# Revision 1.63  2002/02/12 08:08:55  grubert
+#  . Clean up mail handling, multipart handling.
+#
 # Revision 1.62  2002/02/05 14:15:29  grubert
 #  . respect encodings in non multipart messages.
 #

Roundup Issue Tracker: http://roundup-tracker.org/